summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/cio.cc
diff options
context:
space:
mode:
authordshaligram <dshaligram@c06c8d41-db1a-0410-9941-cceddc491573>2008-01-25 18:11:54 +0000
committerdshaligram <dshaligram@c06c8d41-db1a-0410-9941-cceddc491573>2008-01-25 18:11:54 +0000
commit32a6373c7a8072bfcb4567417f82f700084b6ab8 (patch)
tree248900b93f0f79c36123dc92364ccf9b0db3bcee /crawl-ref/source/cio.cc
parent0136740f19467e681f934718d109748458fa49c6 (diff)
downloadcrawl-ref-32a6373c7a8072bfcb4567417f82f700084b6ab8.tar.gz
crawl-ref-32a6373c7a8072bfcb4567417f82f700084b6ab8.zip
Fix collision between gotoxy(int,int,int) and DOS djgpp gotoxy().
git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@3337 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/cio.cc')
-rw-r--r--crawl-ref/source/cio.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/crawl-ref/source/cio.cc b/crawl-ref/source/cio.cc
index fcaaa7adc1..f51b3a49bd 100644
--- a/crawl-ref/source/cio.cc
+++ b/crawl-ref/source/cio.cc
@@ -167,7 +167,7 @@ int c_getch()
#endif
}
// Wrapper around gotoxy that can draw a fake cursor for Unix terms where
// cursoring over darkgray or black causes problems.
void cursorxy(int x, int y)
{
@@ -177,9 +177,9 @@ void cursorxy(int x, int y)
if (Options.use_fake_cursor)
fakecursorxy(x, y);
else
- gotoxy(x, y, GOTO_DNGN);
+ cgotoxy(x, y, GOTO_DNGN);
#else
- gotoxy(x, y, GOTO_DNGN);
+ cgotoxy(x, y, GOTO_DNGN);
#endif
}
@@ -216,7 +216,7 @@ int wrapcprintf( int wrapcol, const char *s, ... )
run[avail] = c;
if ((len -= avail) > 0)
- gotoxy(1, y + 1);
+ cgotoxy(1, y + 1);
run += avail;
}
return (olen);
@@ -321,7 +321,7 @@ void line_reader::cursorto(int ncx)
{
int x = (start_x + ncx - 1) % wrapcol + 1;
int y = start_y + (start_x + ncx - 1) / wrapcol;
- ::gotoxy(x, y, GOTO_LAST);
+ ::cgotoxy(x, y, GOTO_LAST);
}
int line_reader::read_line(bool clear_previous)
@@ -167,7 +167,7 @@ int c_getch()
#endif
}
-// Wrapper around gotoxy that can draw a fake cursor for Unix terms where
+// Wrapper around cgotoxy that can draw a fake cursor for Unix terms where
// cursoring over darkgray or black causes problems.
void cursorxy(int x, int y)